#!/usr/bin/env python
#
# Data Quality Checker also known as DQC
#
# Read the README.md for more detailed information
#
# Barcerlona Supercomputing Center - Centro Nacional de Supercomputacion
#        Earth Sciences Department - Computational Earth Sciences
#     
#     Authors: Ivan Jose Cernicharo Ortiz (ivan.cernicharo@bsc.es)
#             -
#             -
#

import sys
import logging
import datetime

def all_checks():
    return {
        "file_format":"test00_file_format",
        "standard_compliance":"test01_standard_compliance",
        "spatial_completeness":"test02_spatial_completeness",
        "temporal_completness":"test03_temporal_completeness",
        "spatial_consistency":"test04_spatial_consistency",
        "temporal_consistency":"test05_temporal_consistency",
        "valid_ranges":"test06_valid_ranges"
    }

class checker_body:

    def __init__(self,name):
        self.name = name
        self.version = "0.0.1"
        self.help_mssg()

    def __version__(self):
        string = "\nData Quality Checker Wrapper Version: " + self.version + "\n"
        print(string)

    def help_mssg(self):
        string = "\n#"+ "#" * 80 + "\n#\n"
        string += "#"+ " " * 2+"Data Quality Checker Help message - How to run the DQC:\n#\n"
        string += "#"+ " " * 4+"$ python checker.py --test <type of test> [[other arguments in function of the test]] --input <file or folder>\n#\n"
        string += "#\tType of tests available: fileformat\n"
        string += "#\t                         standard_compliance\n"
        string += "#\t                         spatial_completeness\n"
        string += "#\t                         temporal_completeness\n"
        string += "#\t                         spatial_consistency\n"
        string += "#\t                         temporal_consistency\n"
        string += "#\t                         valid_ranges\n#\n"
        string += "#"+ " " * 4+"Some of these tests needs additional arguments as listed below:\n#\n"
        string += "#\t1. If <type of test> == fileformat\n"
        string += "#"+ " " * 2+"$ python checker.py --test fileformat --input <file or folder>\n#\n"
        string += "#\t2. If <type of test> == standard_compliance\n"
        string += "#"+ " " * 2+"$ python checker.py --test standard_compliance --type <e.g.: seasonal_grib,seasonal_netcdf, cmip5 netcdf,...> --input <file or folder>\n#\n"
        string += "#\t3. If <type of test> == spatial_completeness\n"
        string += "#"+ " " * 2+"$ python checker.py --test spatial_completeness --grid <resolution(e.g.: r256x128)> --input <file or folder>\n#\n"
        string += "#\t4. If <type of test> == temporal_completeness\n"
        string += "#"+ " " * 2+"$ python checker.py --test temporal_completeness --temporal_range <time interval(e.g.: 1979-01-01/2019-05-01)> --input <file or folder>\n#\n"
        string += "#\t5. If <type of test> == spatial_consistency\n"
        string += "#"+ " " * 2+"$ python checker.py --test spatial_consistency --space_interval <spatial grid(e.g.: 1 degree)> --input <file or folder>\n#\n"
        string += "#\t6. If <type of test> == temporal_consistency\n"
        string += "#"+ " " * 2+"$ python checker.py --test temporal_consistency --time_interval <e.g.: 1 hourly, 6 hourly, daily, monthly> --input <file or folder>\n#\n"
        string += "#\t7. If <type of test> == valid_ranges\n"
        string += "#"+ " " * 2+"$ python checker.py --test valid_ranges --var <variable (i.e.: tas, 2mt, t,..)> --input <file or folder>\n#\n"
        string += "#" + "#" * 80 + "\n"

        self.help = string

def main(args):
    dqc = checker_body("testing")
    dqc.__version__()

    try:
        conditional1 = (args[0] != "--test" and (args[2] == "--input" or args[4] == "--input"))
        conditional2 = (args[0] in ["--help","-h","help","sos","commands"])

    except:
        print(dqc.help)
        sys.exit()
    
    if conditional1 or conditional2:
        print(dqc.help)
        sys.exit()

    if args[1] not in all_checks().keys():
        print(dqc.help)
        sys.exit()

    if not conditional1 and not conditional2:
        print("Lets put our hands to work")

        if args[1] == 'file_format':
            import test00_file_format
            file_format_check = test00_file_format.file_format_check(args[3])
            print(file_format_check.return_extensions_format())

if __name__ == "__main__":
    args = sys.argv[1:]

    sys.exit(main(args))